# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2010 Tiny SPRL (<http://tiny.be>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

import time
from tools.translate import _

from report import report_sxw
from report.report_sxw import rml_parse

class Parser(report_sxw.rml_parse):
    def __init__(self, cr, uid, name, context):
        super(Parser, self).__init__(cr, uid, name, context)
        
        self.lang = context.get('lang', 'es_ES')
        
        self.pricelist_id = context['pricelist_id']
        self.pricelist = self.pool.get('product.pricelist').browse(self.cr, self.uid, self.pricelist_id, context=context)
        # This is set so when we call product.price we get the price based on the pricelist selected in the wizard
        context['pricelist'] = self.pricelist_id
        
        self.category_ids = context['category_ids']
        self.categories = self.pool.get('product.category').browse(self.cr, self.uid, self.category_ids, context=context)
        if not isinstance(self.categories, list):
            self.categories = [self.categories]
        
        self.products = self.get_products(self.category_ids, context=context)
        if not isinstance(self.products, list):
            self.products = [self.products]
        
        self.localcontext.update({
            'lang': self.lang,
            'categories': self.categories,
            'products': self.products,
            'pricelist': self.pricelist,
            'today': time.localtime(),
        })
        
        self.localcontext.update({
            'label_products': _('Products'),
            'label_name': _('Name'),
            'label_category': _('Category'),
            'label_description': _('Description'),
            'label_code': _('Code'),
            'label_price': _('Price'),
        })
    
    def get_products(self, category_ids, context=None):
        if not isinstance(category_ids, list):
            category_ids = [category_ids]
        template_ids = self.pool.get('product.template').search(self.cr, self.uid, [('categ_id', 'in', category_ids)], context=context)
        if not isinstance(template_ids, list):
            template_ids = [template_ids]
        product_ids = self.pool.get('product.product').search(self.cr, self.uid, [('product_tmpl_id', 'in', template_ids)], context=context)
        products = self.pool.get('product.product').browse(self.cr, self.uid, product_ids, context=context)
        return products





